unit Viewer;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Jpeg;

type
  TfrmImageView = class(TForm)
    procedure FormCreate(Sender: TObject);
    procedure FormPaint(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure FormMouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
    procedure FormMouseUp(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure FormResize(Sender: TObject);
    procedure FormKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
  private
    ImageNum : Integer;
    Jpg : TJpegImage;
    NextImg : TJpegImage;
    Mx, My : Integer;
    Px, Py : integer;
    Moving : Boolean;
  public
    procedure ViewImage(Num : Integer);
  end;

implementation

uses Browser;

{$R *.DFM}

procedure TfrmImageView.FormCreate(Sender: TObject);
begin
  Jpg:=TJpegImage.Create;
end;

procedure TfrmImageView.FormPaint(Sender: TObject);
begin
  Canvas.Draw(Px,Py,Jpg);
  if not Assigned(NextImg) then
  Begin
    if ImageNum+1>=frmBrowser.Images.Count then Exit;
    NextImg:=TJpegImage.Create;
    frmBrowser.LoadImage(frmBrowser.Images[ImageNum+1],NextImg);
    NextImg.DIBNeeded;
  End;
end;

procedure TfrmImageView.FormDestroy(Sender: TObject);
begin
  Jpg.Free;
  NextImg.Free;
end;

procedure TfrmImageView.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  Action:=caFree;
end;

procedure TfrmImageView.ViewImage(Num : Integer);
Begin
  if Num>=frmBrowser.Images.Count then Exit;
  ImageNum:=Num;
  if (not Assigned(NextImg)) or NextImg.Empty then
    frmBrowser.LoadImage(frmBrowser.Images[Num],Jpg)
  else
  Begin
    Jpg.Free;
    Jpg:=NextImg;
    NextImg:=nil;
  End;
  Jpg.DIBNeeded;
  if Jpg.Width<Screen.Width-10 then ClientWidth:=Jpg.Width else Width:=Screen.Width;
  if Jpg.Height<Screen.Height-10 then ClientHeight:=Jpg.Height else Height:=Screen.Height;

  Px:=ClientWidth div 2 - Jpg.Width div 2;
  Py:=ClientHeight div 2 - Jpg.Height div 2;

  Caption:=frmBrowser.Images[Num];
  Show;
  Left:=Screen.Width div 2 - Width div 2;
  Top:=Screen.Height div 2 - Height div 2;
End;

procedure TfrmImageView.FormMouseDown(Sender: TObject; Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
  if Button=mbLeft then
  Begin
    Mx:=X-Px;
    My:=Y-Py;
    Moving:=True;
  End;
end;

procedure TfrmImageView.FormMouseMove(Sender: TObject; Shift: TShiftState; X, Y: Integer);
begin
  if Moving then
  Begin
    if Jpg.Width>ClientWidth then
    Begin
      Px:=X-Mx;
      if Px>0 then Px:=0;
      if Px+Jpg.Width<ClientWidth then Px:=ClientWidth-Jpg.Width;
    End Else Px:=ClientWidth div 2 - Jpg.Width div 2;

    if Jpg.Height>ClientHeight then
    Begin
      Py:=Y-My;
      if Py>0 then Py:=0;
      if Py+Jpg.Height<ClientHeight then Py:=ClientHeight-Jpg.Height;
    End Else Py:=ClientHeight div 2 - Jpg.Height div 2;
    FormPaint(nil);
  End;
end;

procedure TfrmImageView.FormMouseUp(Sender: TObject; Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
  if Button=mbLeft then Moving:=False;
end;

procedure TfrmImageView.FormResize(Sender: TObject);
begin
  if Jpg.Width<=ClientWidth then Px:=ClientWidth div 2 - Jpg.Width div 2;
  if Jpg.Height<=ClientHeight then Py:=ClientHeight div 2 - Jpg.Height div 2;
  Invalidate;
end;

procedure TfrmImageView.FormKeyDown(Sender: TObject; var Key: Word; Shift: TShiftState);
begin
  if Key=VK_NEXT then
  Begin
    if ImageNum+1>=frmBrowser.Images.Count then Exit;
    Jpg.Free;
    Jpg:=TJpegImage.Create;
    ViewImage(ImageNum+1);
    Invalidate;
  End;
end;

end.
